@@ -1,7 +1,7 @@
 package Bencher::Scenarios::LoggingModules;
 
-our $DATE = '2019-02-22'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2021-04-09'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 1;
 # ABSTRACT: Benchmark logging modules
@@ -18,7 +18,7 @@ Bencher::Scenarios::LoggingModules - Benchmark logging modules
 
 =head1 VERSION
 
-This document describes version 0.003 of Bencher::Scenarios::LoggingModules (from Perl distribution Bencher-Scenarios-LoggingModules), released on 2019-02-22.
+This document describes version 0.004 of Bencher::Scenarios::LoggingModules (from Perl distribution Bencher-Scenarios-LoggingModules), released on 2021-04-09.
 
 =head1 DESCRIPTION
 
@@ -40,7 +40,7 @@ Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Lo
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-LoggingModules>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Bencher-Scenarios-LoggingModules/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -52,7 +52,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
